summaryrefslogtreecommitdiff
path: root/include/hashcomp.h
diff options
context:
space:
mode:
authordanieldg <danieldg@e03df62e-2008-0410-955e-edbf42e46eb7>2009-09-02 00:43:25 +0000
committerdanieldg <danieldg@e03df62e-2008-0410-955e-edbf42e46eb7>2009-09-02 00:43:25 +0000
commit219993bc9018d9f0d9568330d7a972b68b785d27 (patch)
tree9d827a0e1a2ad343ebff21fb7f692b1fd2835650 /include/hashcomp.h
parent2630a87bb13b089e6d0fdcff4bcd0f3a9612e52f (diff)
Replace std::deque with std::vector in spanningtree and related modules
git-svn-id: http://svn.inspircd.org/repository/trunk/inspircd@11593 e03df62e-2008-0410-955e-edbf42e46eb7
Diffstat (limited to 'include/hashcomp.h')
-rw-r--r--include/hashcomp.h13
1 files changed, 11 insertions, 2 deletions
diff --git a/include/hashcomp.h b/include/hashcomp.h
index 536c42937..c5d849529 100644
--- a/include/hashcomp.h
+++ b/include/hashcomp.h
@@ -304,7 +304,7 @@ namespace irc
* characters. As specified below, this function
* should be called in a loop until it returns zero,
* indicating there are no more modes to return.
* @param result The deque to populate. This will
* be cleared before it is used.
* @param max_line_size The maximum size of the line
* to build, in characters, seperate to MAXMODES.
@@ -313,7 +313,16 @@ namespace irc
* returns 0, in case there are multiple lines of
* mode changes to be obtained.
*/
- int GetStackedLine(std::deque<std::string> &result, int max_line_size = 360);
+ int GetStackedLine(std::vector<std::string> &result, int max_line_size = 360);
+
+ /** deprecated compatability interface - TODO remove */
+ int GetStackedLine(std::deque<std::string> &result, int max_line_size = 360) {
+ std::vector<std::string> r;
+ int n = GetStackedLine(r, max_line_size);
+ result.clear();
+ result.insert(result.end(), r.begin(), r.end());
+ return n;
+ }
};
/** irc::tokenstream reads a string formatted as per RFC1459 and RFC2812.
@@ -304,7 +304,7 @@ namespace irc
* should be called in a loop until it returns zero,
* indicating there are no more modes to return.
- * @param result The deque to populate. This will
+ * @param result The vector to populate. This will not
* be cleared before it is used.
* @param max_line_size The maximum size of the line